@@ -464,156 +464,6 @@ def SimpleClientMethod(requestClass=None):
         return innerResourceInstanceMethod
     return innerMethodWrapper
 
-@Function
-def Repository(model = None) :
-    repositoryModel = model
-    def Wrapper(OuterClass, *args, **kwargs):
-        log.debug(Repository,f'''wrapping {OuterClass.__name__}''')
-        class InnerClass(OuterClass):
-            model = repositoryModel
-            def __init__(self,*args,**kwargs):
-                log.debug(OuterClass,f'in {InnerClass.__name__}.__init__(*{args},**{kwargs})')
-                OuterClass.__init__(self,*args,**kwargs)
-                apiInstance = getApi()
-                self.repository = apiInstance.repository
-                self.globals = apiInstance.globals
-        ReflectionHelper.overrideSignatures(InnerClass, OuterClass)
-        return InnerClass
-    return Wrapper
-
-@Function
-def Validator() :
-    def Wrapper(OuterClass, *args, **kwargs):
-        log.debug(Validator,f'''wrapping {OuterClass.__name__}''')
-        class InnerClass(OuterClass):
-            def __init__(self,*args,**kwargs):
-                log.debug(OuterClass,f'in {InnerClass.__name__}.__init__(*{args},**{kwargs})')
-                OuterClass.__init__(self,*args,**kwargs)
-                apiInstance = getApi()
-                self.service = apiInstance.resource.service
-                self.validator = apiInstance.resource.validator
-                self.helper = apiInstance.resource.helper
-                self.converter = apiInstance.resource.converter
-        ReflectionHelper.overrideSignatures(InnerClass, OuterClass)
-        return InnerClass
-    return Wrapper
-
-@Function
-def ValidatorMethod(requestClass=None, message=None, logMessage=None) :
-    def innerMethodWrapper(resourceInstanceMethod,*args,**kwargs) :
-        log.debug(ValidatorMethod,f'''wrapping {resourceInstanceMethod.__name__}''')
-        def innerResourceInstanceMethod(*args,**kwargs) :
-            resourceInstance = args[0]
-            try :
-                validateArgs(args,requestClass,innerResourceInstanceMethod)
-                methodReturn = resourceInstanceMethod(*args,**kwargs)
-            except Exception as exception :
-                raiseGlobalException(exception, resourceInstance, resourceInstanceMethod)
-            return methodReturn
-        ReflectionHelper.overrideSignatures(innerResourceInstanceMethod, resourceInstanceMethod)
-        return innerResourceInstanceMethod
-    return innerMethodWrapper
-
-
-@Function
-def Mapper() :
-    def Wrapper(OuterClass, *args, **kwargs):
-        log.debug(Mapper,f'''wrapping {OuterClass.__name__}''')
-        class InnerClass(OuterClass):
-            def __init__(self,*args,**kwargs):
-                log.debug(OuterClass,f'in {InnerClass.__name__}.__init__(*{args},**{kwargs})')
-                OuterClass.__init__(self,*args,**kwargs)
-                apiInstance = getApi()
-                self.service = apiInstance.resource.service
-                self.validator = apiInstance.resource.validator
-                self.mapper = apiInstance.resource.mapper
-                self.helper = apiInstance.resource.helper
-                self.converter = apiInstance.resource.converter
-        ReflectionHelper.overrideSignatures(InnerClass, OuterClass)
-        return InnerClass
-    return Wrapper
-
-@Function
-def MapperMethod(requestClass=None, responseClass=None) :
-    def innerMethodWrapper(resourceInstanceMethod,*args,**kwargs) :
-        log.debug(MapperMethod,f'''wrapping {resourceInstanceMethod.__name__}''')
-        def innerResourceInstanceMethod(*args,**kwargs) :
-            resourceInstance = args[0]
-            try :
-                validateArgs(args,requestClass,innerResourceInstanceMethod)
-                args = getArgsWithResponseClassInstanceAppended(args, responseClass)
-                methodReturn = resourceInstanceMethod(*args,**kwargs)
-            except Exception as exception :
-                raiseGlobalException(exception, resourceInstance, resourceInstanceMethod)
-            return methodReturn
-        ReflectionHelper.overrideSignatures(innerResourceInstanceMethod, resourceInstanceMethod)
-        return innerResourceInstanceMethod
-    return innerMethodWrapper
-
-@Function
-def Helper() :
-    def Wrapper(OuterClass, *args, **kwargs):
-        log.debug(Helper,f'''wrapping {OuterClass.__name__}''')
-        class InnerClass(OuterClass,flask_restful.Resource):
-            def __init__(self,*args,**kwargs):
-                log.debug(OuterClass,f'in {InnerClass.__name__}.__init__(*{args},**{kwargs})')
-                OuterClass.__init__(self,*args,**kwargs)
-                apiInstance = getApi()
-                self.helper = apiInstance.resource.helper
-                self.converter = apiInstance.resource.converter
-        ReflectionHelper.overrideSignatures(InnerClass, OuterClass)
-        return InnerClass
-    return Wrapper
-
-@Function
-def HelperMethod(requestClass=None, responseClass=None) :
-    def innerMethodWrapper(resourceInstanceMethod,*args,**kwargs) :
-        log.debug(HelperMethod,f'''wrapping {resourceInstanceMethod.__name__}''')
-        def innerResourceInstanceMethod(*args,**kwargs) :
-            resourceInstance = args[0]
-            try :
-                validateArgs(args,requestClass,innerResourceInstanceMethod)
-                args = getArgsWithResponseClassInstanceAppended(args, responseClass)
-                methodReturn = resourceInstanceMethod(*args,**kwargs)
-            except Exception as exception :
-                raiseGlobalException(exception, resourceInstance, resourceInstanceMethod)
-            return methodReturn
-        ReflectionHelper.overrideSignatures(innerResourceInstanceMethod, resourceInstanceMethod)
-        return innerResourceInstanceMethod
-    return innerMethodWrapper
-
-@Function
-def Converter() :
-    def Wrapper(OuterClass, *args, **kwargs):
-        log.debug(Converter,f'''wrapping {OuterClass.__name__}''')
-        class InnerClass(OuterClass):
-            def __init__(self,*args,**kwargs):
-                log.debug(OuterClass,f'in {InnerClass.__name__}.__init__(*{args},**{kwargs})')
-                OuterClass.__init__(self,*args,**kwargs)
-                apiInstance = getApi()
-                self.helper = apiInstance.resource.helper
-                self.converter = apiInstance.resource.converter
-        ReflectionHelper.overrideSignatures(InnerClass, OuterClass)
-        return InnerClass
-    return Wrapper
-
-@Function
-def ConverterMethod(requestClass=None, responseClass=None) :
-    def innerMethodWrapper(resourceInstanceMethod,*args,**kwargs) :
-        log.debug(ConverterMethod,f'''wrapping {resourceInstanceMethod.__name__}''')
-        def innerResourceInstanceMethod(*args,**kwargs) :
-            resourceInstance = args[0]
-            try :
-                validateArgs(args, requestClass, innerResourceInstanceMethod)
-                args = getArgsWithResponseClassInstanceAppended(args, responseClass)
-                methodReturn = resourceInstanceMethod(*args,**kwargs)
-            except Exception as exception :
-                raiseGlobalException(exception, resourceInstance, resourceInstanceMethod)
-            return methodReturn
-        ReflectionHelper.overrideSignatures(innerResourceInstanceMethod, resourceInstanceMethod)
-        return innerResourceInstanceMethod
-    return innerMethodWrapper
-
 def getGlobalException(exception, resourceInstance, resourceInstanceMethod):
     apiInstance = getNullableApi()
     return GlobalException.handleLogErrorException(exception, resourceInstance, resourceInstanceMethod, apiInstance)
